#
# spec file for package janino
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           janino
Version:        3.1.10
Release:        2.10
Summary:        An embedded Java compiler
License:        BSD-3-Clause
Group:          Development/Libraries/Java
URL:            https://janino-compiler.github.io/janino
Source0:        https://github.com/janino-compiler/janino/archive/v%{version}/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  java-devel >= 1.8
BuildRequires:  maven-local
BuildRequires:  mvn(junit:junit)
BuildRequires:  mvn(org.apache.ant:ant)
BuildRequires:  mvn(org.apache.felix:maven-bundle-plugin)
Requires:       commons-compiler = %{version}-%{release}
Requires:       javapackages-tools
BuildArch:      noarch

%description
Janino is a super-small, super-fast Java compiler.

The "JANINO" implementation of the "commons-compiler" API: Super-small,
super-fast, independent from the JDK's "tools.jar".

%package     -n commons-compiler
Summary:        Commons Compiler
Group:          Development/Libraries/Java

%description -n commons-compiler
The "commons-compiler" API, including the "IExpressionEvaluator",
"IScriptEvaluator", "IClassBodyEvaluator" and "ISimpleCompiler" interfaces.

%package     -n commons-compiler-jdk
Summary:        Commons Compiler JDK
Group:          Development/Libraries/Java

%description -n commons-compiler-jdk
The "JDK" implementation of the "commons-compiler" API that uses the
JDK's Java compiler (JAVAC) in "tools.jar".

%package        javadoc
Summary:        API documentation for %{name}
Group:          Documentation/HTML

%description    javadoc
API documentation for %{name}.

%prep

%autosetup

find -type f '(' -iname '*.jar' -o -iname '*.class' ')' -print -delete

pushd %{name}-parent
  %pom_xpath_remove pom:maven.compiler.source
  %pom_xpath_remove pom:maven.compiler.target
  %pom_xpath_remove pom:maven.compiler.executable
  %pom_xpath_remove pom:maven.compiler.fork

  %pom_remove_plugin :nexus-staging-maven-plugin
  %pom_remove_plugin :maven-jarsigner-plugin
  %pom_remove_plugin :maven-javadoc-plugin
  %pom_remove_plugin :maven-source-plugin

  %pom_disable_module ../commons-compiler-tests

  %{mvn_package} :%{name}-parent __noinstall
popd

%build

pushd %{name}-parent
  %{mvn_build} -fs -- \
    -Dproject.build.outputTimestamp=$(date -u -d @${SOURCE_DATE_EPOCH:-$(date +%%s)} +%%Y-%%m-%%dT%%H:%%M:%%SZ) \
    -Dmaven.compiler.source=8 -Dmaven.compiler.target=8
popd

%install

pushd %{name}-parent
  %mvn_install
  %fdupes -s %{buildroot}%{_javadocdir}

  %jpackage_script org.codehaus.commons.compiler.samples.CompilerDemo "" "" %{name}/janino:%{name}/commons-compiler janinoc true
popd

%files -f %{name}-parent/.mfiles-%{name}
%license LICENSE
%{_bindir}/janinoc

%files -n commons-compiler -f %{name}-parent/.mfiles-commons-compiler
%license LICENSE

%files -n commons-compiler-jdk -f %{name}-parent/.mfiles-commons-compiler-jdk
%license LICENSE

%files javadoc -f %{name}-parent/.mfiles-javadoc
%license LICENSE

%changelog
* Sat Sep  9 2023 Fridrich Strba <fstrba@suse.com>
- Reproducible builds: use SOURCE_DATE_EPOCH for timestamp
* Tue Aug 15 2023 Fridrich Strba <fstrba@suse.com>
- Upgrade to version 3.1.10
  * Fixed issue #205: Classpath: Class archive file naming: Removed
    the file name check for class file archives; previously: *.jar
    and *.zip
  * Fixed issue #201: A Stack overflow error: Catch
    StackOverflowError in all relevant API methods 8e.g. "cook()"
    and "guessParameterNames()") and convert it into a
    CompileException (bsc#1211923, CVE-2023-33546).
  * Fixed issue #204: Evaluate method is ambiguous: Changed method
    "evaluate(Object...)" back to "evaluate(Object[])", and added a
    method "evaluate()" for convenience.
  * Fixed issue #202: Gracefully degradation if loading system
    properties throws an SecurityException
  * Fixed issue #182: Incompatible return types, when there are
    multiple methods with different return type
  * Fixed issue #188: Some expressions are failing without explicit
    cast of null
  * C++-style comment before EOI caused an internal compiler error.
  * Fixed issue #195: "Redefinition of constructors and methods
    allowed".
  * AutoIndentWriter: flush() / close(): The "tabulatorBuffer" and
    the "lineBuffer" were flushed in the wrong order, leaving the
    tabulatorBuffer unflushed under some conditions.
  * Fixed issue #196: "First type argument in ReferenceType lose
    its type arguments".
  * Fixed issue #183: "Add Automatic-Module-Name to MANIFEST.MF".
- Upgrade to version 3.1.9
  * Merged pr #189 "Implement implicit conversions to Arrays with
    Annotations".
  * Reproduce issue #188 "Some expressions are failing without
    explicit cast of null".
  * Fixed issue #187 "Compilation of vars initialized in different
    if/else branches is failing".
  * Fixed issue #185 "InternalCompilerException while compiling
    variables initialized in while condition".
  * Added the "-benchmark" command line option.
  * Fixed issue #182 "Incompatible return types, when there are
    multiple methods with different return type".
  * Eliminated generation of empty StackMapTable attributes.
- Upgrade to version 3.1.8
  * Generation of the StackMapTable is finally correct! However,
    the default tar version is still 6.
  * Regression tests finally pass for target version 8!
  * Fixed an AccessControlException with JRE 7.
  * Fixed issue #172 "SimpleCompiler Variable Bug", and also for
    VOID return type. Added test cases for issue 172 "SimpleCompiler
    Variable Bug".
  * Added more test cases for the "ConstantValue" attribute.
  * Added fix and regression test case for issue #177
    "ClassFormatError when assigning integer to constant double".
    Added test cases.
  * Fixed issue #174: "Byte code is 350 times larger due to
    StackMapTable, JVM crashes when loading the class". Added test
    cases.
  * Implementing nested types didn't work (dollar signs in class
    name).
  * Added code for debugging the loading of .class file and source
    files.
  * Added fix and regression test case for issue #178 "Janino
    incorrectly thinks variables are uninitialized". Added
    regression test cases.
  * Issue #176: "String s = System.out.println();" throws an
    InternalCompilerException
  * Implemented a system property
    "org.codehaus.janino.CodeContext.suppressStackMapTable"
    (boolean).
  * Fixed Issue #168 "commons-compiler-jdk: Unable to load class".
  * Added JDISASM with scope "test" because some test cases now need
    JDISASM.
  * Fixed GITHUB PR #10: Replace if condition with literal if
    possible to simplify if statement
  * Allow variable declarators between the LV declaration and the IF
    statement iff none of the VDs modify the LV.
  * Added "-Xverify:all" to all run configuration to enforce the
    strictest bytecode verification possible.
  * Test case "JlsTest.test_9_7_1__Normal_Annotations2()" choked
    because of annotation-type element value (annotation type is
    described by an UTF8 CPE, not a CLASS CPE).
  * Fixed issue #167 "After a successful compilation, compiling
    identical (or similar) code fails with an assignment conversion
    error".
  * Moved the "getArrayIClass(...)" methods from "IClass" to
    "IClassLoader", and keep the array classes per-class-loader
    (which is important because arrays refer to java.lang.Object).
    Also added a test case.
  * Removed JUnit launch configurations for Java 12, 15 and 16,
    which are no longer supported.
- Upgrade to version 3.1.7
  * Merged PR #148 "Correct the logic to truncate Stack map in
    CodeContext.restoreLocalVariables".
  * Merged PR #163 "Add SUPER flag for package member types only
    (#163)".
  * Fixed issue #166 "Get generate method bytecode size".
  * Added a test case for issue #165.
  * Fixed issue #165 "Compilation failure when a class and package
    name match case insensitively".
  * Replaced "new (Byte|Short|Integer|Long|Float|Double|Character
    |Boolean)(...)" with "valueOf(...)".
  * Replaced types "Visitor.*Visitor" with "*Visitor".
  * Fixed issue #135 again; this time right.
  * Fixed Issue #155 "Enhanced FOR statement does not work with
    primitive variable".
  * Verified compatibility with Java 17.
  * Began to extend IClass and ClassFile for generics; specifically
    added IType and ITypeVariable. However generics are not yet
    supported; work in progress (although regression tested).
  * Implemented private interface methods (a Java 9 feature).
  * Further simplified the
    org.codehaus.commons.compiler.jdk.SimpleCompiler: It now uses a
    delegate o.c.c.c.j.Compiler, which saves a lot of duplicate
    code.
  * Major refactoring of org.codehaus.commons.compiler.jdk to get
    rid of duplicate code.
  * Fixed the error handling of the
    o.c.c.c.jdk.(Compiler|SimpleCompiler); added respective test
    cases.
  * Marking the SimpleCompiler as "cooked" was not reliable.
  * Static and default interface methods were still declared as "not
    implemented" on the home page, while they are already
    implemented! Updated the home page, added some test cases and
    fixed a minor bug.
  * Added a test for the "diamond operator".
  * Removed all "redundant type arguments", i.e. made use of the
    "diamond operator". This became possible because support was
    dropped for Java 6.
  * Also dropped support for "funny" intermediate Java versions 9
    and 10.
  * Dropped support for Java 6. Thus, Janino is now compiled against
    the JRE 7 runtime.
* Tue Mar 22 2022 Fridrich Strba <fstrba@suse.com>
- Upgrade to version 3.1.6
  * Fixed issue #151: Calcite tests fail with compiler error
  * Added a test case that reproduces issue #151.
  * #141 Class loader workaround so that Calcite doesn't need to
    change. (#150)
- Removed patch:
  * janino-2.7.8-remove-nullanalysis-annotations.patch
    + not needed any more
- Build with source and target levels 8
* Tue Nov 12 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of janino 2.7.8
